Documentation
¶
Index ¶
- Constants
- Variables
- func Filename(configRoot string) (string, error)
- func Marshal(value interface{}) ([]byte, error)
- func Path(configRoot, configFile string) (string, error)
- func PathRoot() (string, error)
- type Bootstrap
- type Config
- type Datastore
- type DirectAnnounce
- type Identity
- type Ingest
- type ProviderServer
Constants ¶
const ( // DefaultPathName is the default config dir name. DefaultPathName = ".index-provider" // DefaultPathRoot is the path to the default config dir location. DefaultPathRoot = "~/" + DefaultPathName // DefaultConfigFile is the filename of the configuration file. DefaultConfigFile = "config" // EnvDir is the environment variable used to change the path root. EnvDir = "PROVIDER_PATH" )
const (
PrivateKeyPathEnvVar = "INDEXPROVIDER_PRIV_KEY_PATH"
)
Variables ¶
var ( ErrInitialized = errors.New("configuration file already exists") ErrNotInitialized = errors.New("not initialized") )
var ErrInvalidPeerAddr = errors.New("invalid peer address")
ErrInvalidPeerAddr signals an address is not a valid peer address.
Functions ¶
func Filename ¶
Filename returns the configuration file path given a configuration root directory. If the configuration root directory is empty, use the default.
Types ¶
type Bootstrap ¶
type Bootstrap struct {
// Peers is the local nodes's bootstrap peer addresses
Peers []string
// MinimumPeers governs whether to bootstrap more connections. If the node
// has less open connections than this number, it will open connections to
// the bootstrap nodes. Set to 0 to disable bootstrapping.
MinimumPeers int
}
func NewBootstrap ¶
func NewBootstrap() Bootstrap
NewBootstrap instantiates a new Bootstrap config with default values.
type Config ¶
type Config struct {
Identity Identity
Datastore Datastore
Ingest Ingest
ProviderServer ProviderServer
Bootstrap Bootstrap
DirectAnnounce DirectAnnounce
}
Config is used to load config files.
func InitWithIdentity ¶
func (*Config) PopulateDefaults ¶
func (c *Config) PopulateDefaults()
type Datastore ¶
type Datastore struct {
// Type is the type of datastore
Type string
// Dir is the directory within the config root where the datastore is kept
Dir string
}
Datastore tracks the configuration of the datastore.
func NewDatastore ¶
func NewDatastore() Datastore
NewDatastore instantiates a new Datastore config with default values.
func (*Datastore) PopulateDefaults ¶
func (c *Datastore) PopulateDefaults()
PopulateDefaults replaces zero-values in the config with default values.
type DirectAnnounce ¶
type DirectAnnounce struct {
// URLs is a list of indexer URLs to send HTTP announce messages to.
URLs []string
}
DirectAnnounce configures the target indexers that advertisement announce messages are sent directly to via HTTP.
func NewDirectAnnounce ¶
func NewDirectAnnounce() DirectAnnounce
NewDirectAnnounce returns DirectAnnounce with values set to their defaults.
type Identity ¶
Identity tracks the configuration of the local node's identity.
func CreateIdentity ¶
CreateIdentity initializes a new identity.
func (Identity) DecodeOrCreate ¶
func (Identity) DecodeOrCreatePrivateKey ¶
func (identity Identity) DecodeOrCreatePrivateKey(out io.Writer, passphrase string) (ic.PrivKey, error)
DecodeOrCreatePrivateKey is a helper to decode the user's PrivateKey. If the key hasn't been provided in json config then it's going to be read from PrivateKeyPathEnvVar. If that file doesn't exist then a new key is going to be generated and saved there.
type Ingest ¶
type Ingest struct {
// LinkCacheSize is the maximum number of links that cash can store before
// LRU eviction. If a single linked list has more links than the cache can
// hold, the cache is resized to be able to hold all links.
LinkCacheSize int
// LinkedChunkSize is the number of multihashes in each chunk of in the
// advertised entries linked list. If multihashes are 128 bytes, then
// setting LinkedChunkSize = 16384 will result in blocks of about 2Mb when
// full.
LinkedChunkSize int
// PurgeLinkCache tells whether to purge the link cache on daemon startup.
PurgeLinkCache bool
// AnnounceMultiaddr is the address supplied in the announce message
// telling indexers the address to use to retrieve advertisements. If not
// specified, the ListenMultiaddr is used.
AnnounceMultiaddr string
// ListenMultiaddr is the address of the interface to listen for HTTP
// requests for advertisements.
ListenMultiaddr string
}
Ingest configures settings related to the ingestion protocol.
func NewIngest ¶
func NewIngest() Ingest
NewIngest instantiates a new Ingest configuration with default values.
func (*Ingest) ListenNetAddr ¶
func (*Ingest) PopulateDefaults ¶
func (c *Ingest) PopulateDefaults()
PopulateDefaults replaces zero-values in the config with default values.
type ProviderServer ¶
type ProviderServer struct {
// ListenMultiaddr is the multiaddr string for the node's listen address
ListenMultiaddr string
// ControlAddr is where to run the http control server
ControlAddr string
// RetrievalMultiaddrs are the addresses to advertise for data retrieval.
// Defaults to the provider's libp2p host listen addresses.
RetrievalMultiaddrs []string
}
func NewProviderServer ¶
func NewProviderServer() ProviderServer
NewProviderServer instantiates a new ProviderServer config with default values.
func (*ProviderServer) PopulateDefaults ¶
func (c *ProviderServer) PopulateDefaults()
PopulateDefaults replaces zero-values in the config with default values.